/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package de.bsvrz.ste.rdstmc.meldungserstellung;

/**
 * Location-Methode zum Erstellen von Meldungen
 * 
 * @author Dambach Werke
 * @version $Revision: 1.1 $ / $Date: 2009/01/27 13:54:22 $ / ($Author: Sans $)
 */
public enum LocationMethode
{
  LISTE(0, "erste Feldposition ist primäre Location und letzte Feldposition ist sekundäre Location"),
  EXTEND(1, "Primäre Location und Extent sind gültig");

  /**
   * Numerische Darstellung der Location-Methode
   */
  public final int id;

  /**
   * Text-Darstellung der Location-Methode
   */
  public final String text;

  @Override
  public String toString()
  {
    return text;
  }

  /**
   * @param id der LocationMethode
   * @return die zur übergebenen Id gehörende LocationMethode oder null,
   * falls es zur Id keine LocationMethode gibt
   */
  public static LocationMethode get(int id)
  {
    for (LocationMethode methode: values())
    {
      if (methode.id == id)
      {
        return methode;
      }
    }
    return null;
  }
  
  /**
   * Privater Konstruktor
   */
  private LocationMethode(int id, String text)
  {
    this.id = id;
    this.text = text;
  }
  
} 
